@@ -1,12 +1,12 @@
 # Natural Language Toolkit: An Incremental Earley Chart Parser
 #
-# Copyright (C) 2001-2021 NLTK Project
+# Copyright (C) 2001-2024 NLTK Project
 # Author: Peter Ljunglöf <peter.ljunglof@heatherleaf.se>
 #         Rob Speer <rspeer@mit.edu>
 #         Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Jean Mark Gawron <gawron@mail.sdsu.edu>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -112,7 +112,7 @@ class IncrementalChart(Chart):
 
     def _register_with_indexes(self, edge):
         end = edge.end()
-        for (restr_keys, index) in self._indexes.items():
+        for restr_keys, index in self._indexes.items():
             vals = tuple(getattr(edge, key)() for key in restr_keys)
             index[end].setdefault(vals, []).append(edge)
 
@@ -165,7 +165,7 @@ class FeatureIncrementalChart(IncrementalChart, FeatureChart):
 
     def _register_with_indexes(self, edge):
         end = edge.end()
-        for (restr_keys, index) in self._indexes.items():
+        for restr_keys, index in self._indexes.items():
             vals = tuple(
                 self._get_type_if_possible(getattr(edge, key)()) for key in restr_keys
             )
