@@ -1,10 +1,10 @@
 # Natural Language Toolkit: Stemmers
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2024 NLTK Project
 # Author: Trevor Cohn <tacohn@cs.mu.oz.au>
 #         Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -22,11 +22,13 @@ StemmerI defines a standard interface for stemmers.
 """
 
 from nltk.stem.api import StemmerI
-from nltk.stem.regexp import RegexpStemmer
-from nltk.stem.lancaster import LancasterStemmer
+from nltk.stem.arlstem import ARLSTem
+from nltk.stem.arlstem2 import ARLSTem2
+from nltk.stem.cistem import Cistem
 from nltk.stem.isri import ISRIStemmer
+from nltk.stem.lancaster import LancasterStemmer
 from nltk.stem.porter import PorterStemmer
+from nltk.stem.regexp import RegexpStemmer
+from nltk.stem.rslp import RSLPStemmer
 from nltk.stem.snowball import SnowballStemmer
 from nltk.stem.wordnet import WordNetLemmatizer
-from nltk.stem.rslp import RSLPStemmer
-from nltk.stem.cistem import Cistem
