@@ -1,16 +1,16 @@
 # Natural Language Toolkit: TnT Tagger
 #
-# Copyright (C) 2001-2021 NLTK Project
+# Copyright (C) 2001-2024 NLTK Project
 # Author: Sam Huston <sjh900@gmail.com>
 #
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
 Implementation of 'TnT - A Statisical Part of Speech Tagger'
 by Thorsten Brants
 
-http://acl.ldc.upenn.edu/A/A00/A00-1031.pdf
+https://aclanthology.org/A00-1031.pdf
 """
 
 from math import log
@@ -88,13 +88,13 @@ class TnT(TaggerI):
         before being used to tag input.
 
         :param unk: instance of a POS tagger, conforms to TaggerI
-        :type  unk:(TaggerI)
+        :type  unk: TaggerI
         :param Trained: Indication that the POS tagger is trained or not
-        :type  Trained: boolean
+        :type  Trained: bool
         :param N: Beam search degree (see above)
-        :type  N:(int)
+        :type  N: int
         :param C: Capitalization flag
-        :type  C: boolean
+        :type  C: bool
 
         Initializer, creates frequency distributions to be used
         for tagging
@@ -149,7 +149,6 @@ class TnT(TaggerI):
         for sent in data:
             history = [("BOS", False), ("BOS", False)]
             for w, t in sent:
-
                 # if capitalization is requested,
                 # and the word begins with a capital
                 # set local flag C to True
@@ -205,7 +204,6 @@ class TnT(TaggerI):
             # (NOTE: tag actually represents (tag,C))
             # However no effect within this function
             for tag in self._tri[history].keys():
-
                 # if there has only been 1 occurrence of this tag in the data
                 # then ignore this trigram.
                 if self._uni[tag] == 1:
@@ -352,7 +350,7 @@ class TnT(TaggerI):
         if word in self._wd:
             self.known += 1
 
-            for (history, curr_sent_logprob) in current_states:
+            for history, curr_sent_logprob in current_states:
                 logprobs = []
 
                 for t in self._wd[word].keys():
@@ -387,7 +385,7 @@ class TnT(TaggerI):
                 [(_w, t)] = list(self._unk.tag([word]))
                 tag = (t, C)
 
-            for (history, logprob) in current_states:
+            for history, logprob in current_states:
                 history.append(tag)
 
             new_states = current_states
@@ -452,7 +450,7 @@ def basic_sent_chop(data, raw=True):
                 curr_sent.append(word)
 
     else:
-        for (word, tag) in data:
+        for word, tag in data:
             if word in sent_mark:
                 curr_sent.append((word, tag))
                 new_data.append(curr_sent)
@@ -492,7 +490,7 @@ def demo2():
     s.train(d[(11) * 100 :])
 
     for i in range(10):
-        tacc = t.evaluate(d[i * 100 : ((i + 1) * 100)])
+        tacc = t.accuracy(d[i * 100 : ((i + 1) * 100)])
         tp_un = t.unknown / (t.known + t.unknown)
         tp_kn = t.known / (t.known + t.unknown)
         t.unknown = 0
@@ -504,7 +502,7 @@ def demo2():
         print("Percentage unknown:", tp_un)
         print("Accuracy over known words:", (tacc / tp_kn))
 
-        sacc = s.evaluate(d[i * 100 : ((i + 1) * 100)])
+        sacc = s.accuracy(d[i * 100 : ((i + 1) * 100)])
         sp_un = s.unknown / (s.known + s.unknown)
         sp_kn = s.known / (s.known + s.unknown)
         s.unknown = 0
@@ -537,7 +535,6 @@ def demo3():
     sknown = 0
 
     for i in range(10):
-
         t = TnT(N=1000, C=False)
         s = TnT(N=1000, C=False)
 
@@ -550,14 +547,14 @@ def demo3():
         t.train(dtrain)
         s.train(etrain)
 
-        tacc = t.evaluate(dtest)
+        tacc = t.accuracy(dtest)
         tp_un = t.unknown / (t.known + t.unknown)
         tp_kn = t.known / (t.known + t.unknown)
         tknown += tp_kn
         t.unknown = 0
         t.known = 0
 
-        sacc = s.evaluate(etest)
+        sacc = s.accuracy(etest)
         sp_un = s.unknown / (s.known + s.unknown)
         sp_kn = s.known / (s.known + s.unknown)
         sknown += sp_kn
